@@ -17,6 +17,26 @@ class _User():
     def __init__(self, rosec):
         self._rosec = rosec
     
+    def Check(self, user):
+        isint = True
+        try:
+            user = int(user)
+        except:
+            isint = None
+        if not isint:
+            el = requests.get("https://api.roblox.com/users/get-by-username", params={"username": user})
+            el = json.loads(el.text)
+            if "success" in el:
+                return el["errorMessage"]
+            else:
+                user = el["Id"]
+        el = requests.get(f"https://users.roblox.com/v1/users/{user}")
+        el = json.loads(el.text)
+        if "errors" not in el:
+            return {"exist": True}
+        else:
+            return {"exist": False}
+    
     def Info(self, user):
         isint = True
         try:
@@ -73,16 +93,27 @@ class _User():
                 user
             ]
         }
-        el = requests.post("https://presence.roblox.com/v1/presence/users", json=params)
+        yesrs = None
+        rosec = self._rosec
+        if rosec:
+            rscheck = checkrs(rosec)
+            if rscheck:
+                yesrs = True
+                el = requests.post("https://presence.roblox.com/v1/presence/users", json=params, cookies={".ROBLOSECURITY": rosec})
+            else:
+                el = requests.post("https://presence.roblox.com/v1/presence/users", json=params)
+        else:
+            el = requests.post("https://presence.roblox.com/v1/presence/users", json=params)
         el = json.loads(el.text)
         if "errors" not in el:
             el = el["userPresences"][0]
             info = {}
-            if  "lastLocation" in el:
-                info["game"] = {
-                    "name": el["lastLocation"]
-                    "link": f"https://www.roblox.com/games/{el['placeId']}"
-                }
+            if yesrs:
+                if el["lastLocation"] not in ["", "Website"]:
+                    info["game"] = {
+                        "name": el["lastLocation"],
+                        "link": f"https://www.roblox.com/games/{el['placeId']}"
+                    }
             if el["userPresenceType"] == 0:
                 activitytype = "Offline"
             elif el["userPresenceType"] == 1:
